CallEntity class

Annotations

Constructors

CallEntity({String? callId, String? userName, String? userImage, bool? callMatch, int? callType, int? toyCost, String? callCost, String? callCostUserId, String? callPackage, String? matchTime, List<MatchCostUser>? matchCostUserId})
CallEntity.fromJson(Map<String, dynamic> json)
factory

Properties

callCost ↔ String?
getter/setter pair
callCostUserId ↔ String?
getter/setter pair
callId ↔ String?
getter/setter pair
callMatch ↔ bool?
getter/setter pair
callPackage ↔ String?
getter/setter pair
callType ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchCostUserId ↔ List<MatchCostUser>?
getter/setter pair
matchTime ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toyCost ↔ int?
getter/setter pair
userImage ↔ String?
getter/setter pair
userName ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited