GiftMessageContent class

Annotations

Constructors

GiftMessageContent({String? giftId, String? name, String? pic, String? url, String? price, String? lottie})
GiftMessageContent.fromJson(Map<String, dynamic> json)
factory

Properties

giftId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lottie ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
pic ↔ String?
getter/setter pair
price ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited