VideoCallWidgetState class

Inheritance

Constructors

VideoCallWidgetState()

Properties

bottomHeight ↔ double
getter/setter pair
call ↔ bool
getter/setter pair
callId ↔ String?
getter/setter pair
callStatus ↔ int
getter/setter pair
channelId ↔ String?
getter/setter pair
closeCamera ↔ bool
getter/setter pair
closeMicrophone ↔ bool
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentDown ↔ int
getter/setter pair
currentRate ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isConnect ↔ bool?
getter/setter pair
isLeave ↔ bool
getter/setter pair
isSendConnect ↔ bool
getter/setter pair
isSoonMoney ↔ bool
getter/setter pair
localVideoStatus ↔ bool
getter/setter pair
match15 ↔ bool
getter/setter pair
matchSoon ↔ bool
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
offline ↔ bool
getter/setter pair
partyLeft ↔ bool
getter/setter pair
quality ↔ int
getter/setter pair
qualityDown ↔ int
getter/setter pair
remoteVideoStatus ↔ bool
getter/setter pair
rtcEngine ↔ RtcEngine?
getter/setter pair
rtcToken ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showTime ↔ bool
getter/setter pair
showVideoView ↔ bool
getter/setter pair
type ↔ int
getter/setter pair
userJoinedRate ↔ int
用户什么时候加入房间
getter/setter pair
userUid ↔ int?
getter/setter pair
widget → VideoCallWidget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addAgoraEventHandlers() → void
addRtmHandler() → void
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
callBefore() → void
callStart() → Future
currentCall() → void
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant VideoCallWidget oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
initRtcEngine() → void
initState() → void
Called when this object is inserted into the tree.
override
joinChannel() → void
leaveChannel([bool keep = false]) → Future
matchStart() → void
matchSuccess() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSetState() → void
printLog(dynamic e) → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
restCallStatus() → void
setBottomHeight(double bottomHeight) → void
setCallStatus(int callStatus) → void
setCloseCamera() → Future<bool>
setCloseMicrophone() → Future<bool>
setShowVideoView() → bool
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showMoney(bool rest) → void
switchCamera() → Future<void>
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
userInHouseCheck() → void
willSendVideo(int status, {int? newTime}) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited